@@ -370,3 +370,30 @@ void nt_res_msg_free(nt_res_tp ptr)
 	}
 }
 
+
+nt_write_data_tp nt_write_data_alloc()
+{
+	nt_write_data_tp writep
+		= (nt_write_data_tp)calloc(1,
+				sizeof(nt_write_data_t));
+	return writep;
+}
+
+void nt_write_data_free(nt_write_data_tp ptr)
+{
+	assert(ptr);
+	if(ptr->name)
+		free(ptr->name);
+	if(ptr->mail)
+		free(ptr->mail);
+	if(ptr->msg)
+		free(ptr->msg);
+	if(ptr->result_html)
+		free(ptr->result_html);
+	if(ptr->cookies)
+		nt_all_link_free(ptr->cookies, free);
+
+	free(ptr);
+}
+
+
