@@ -1,5 +1,13 @@
+#ifndef _ENV_H_
+#define _ENV_H_
+
 extern char LOG_PATH[];
+extern char USR_PATH[];
+extern char USR_COOKIE_PATH[];
 extern int FORCE_REFRESH;
+extern char EDITOR_CMD[];
+extern char *MARU_ID;
+extern char *MARU_PW;
 
 #define NT_KEY_NONE (-1)
 #define NT_KEY_UP 'k'
@@ -20,4 +28,10 @@ extern int FORCE_REFRESH;
 #define NT_KEY_COMMAND3 '?'
 
 
+#define NT_COMMAND1_WRITE_MSG_1 "write"
+#define NT_COMMAND1_WRITE_MSG_2 "w"
+
 extern int set_option(int argc, char* argv[]);
+
+
+#endif /*  _ENV_H_ */
