@@ -1,3 +1,5 @@
+#include <sys/types.h>
+#include <sys/socket.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -5,13 +7,17 @@
 #include <ncursesw/ncurses.h>
 #include <locale.h>
 #include <iconv.h>
+#include <netinet/in.h>
 
 #include "env.h"
 #include "error.h"
 #include "utils/nt_std_t.h"
 #include "net/nt_http.h"
+#include "net/nt_socket.h"
+#include "net/nt_cookie.h"
 #include "utils/file.h"
 #include "_2ch/_2ch.h"
+#include "_2ch/maru_2ch.h"
 #include "ui/disp.h"
 #include "ui/disp_win.h"
 #include "ui/disp_string.h"
@@ -32,6 +38,7 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
+
 	sleep(1);
 
 	setlocale(LC_ALL, "ja_JP.UTF-8");
@@ -63,6 +70,8 @@ int main(int argc, char *argv[])
 	nocbreak();
 
 ERROR_TRAP:
+	clear();
+
 
 	nt_2ch_model_free(app_2ch_modelp);
 	endwin();
@@ -73,13 +82,23 @@ ERROR_TRAP:
 static BOOL DoLoop(WINDOW *scrp)
 {
 	int ch, state, num;
-	int disp_state = DISP_STATE_BOARDMENU; 
+	int disp_state, nresult;
 	nt_window_tp bwinp = NULL;
 	nt_window_tp twinp = NULL;
 	nt_window_tp rwinp = NULL;
 	char buf[256];
 	wchar_t wch, *title;
+	wchar_t *status_msg = NULL;
 	BOOL result = FALSE;
+	nt_write_data_tp writep = NULL;
+	nt_maru_2ch_tp marup = NULL;
+	nt_cookie_tp cookiep;
+
+	disp_state = DISP_STATE_BOARDMENU; 
+	cookiep = nt_load_cookies(USR_COOKIE_PATH);
+
+	if(MARU_ID && MARU_PW) 
+		marup = nt_maru_2ch_alloc(MARU_ID, MARU_PW);
 
 	ch = NT_KEY_NONE;
 	bwinp = nt_disp_win_alloc(scrp, LINES-1, COLS, 1, 0, buf);
@@ -138,6 +157,8 @@ static BOOL DoLoop(WINDOW *scrp)
 					ch = NT_KEY_NONE;
 					continue;
 				}else if(DISP_STATE_RESLIST == state){
+					if(!nt_read_thread(app_2ch_modelp))
+						break;
 					if(rwinp->data){
 						free_reslist_ctx(rwinp->data);
 						rwinp->data = NULL;
@@ -164,7 +185,58 @@ static BOOL DoLoop(WINDOW *scrp)
 				ch = NT_KEY_NONE;
 				continue;
 			}
+			if(status_msg){
+				print_error(scrp, status_msg);
+				status_msg = NULL;
+			}
 			break;
+		case DISP_STATE_EDITOR:
+			disp_state = DISP_STATE_RESLIST;
+			ch = NT_KEY_NONE;
+			if(writep)
+				nt_write_data_free(writep);
+			writep = nt_write_data_alloc();
+			if(!writep)
+				goto END_WHILE;
+			if(disp_editor(writep)){
+				if(marup && !marup->sid)
+					get_session_id(marup);
+				if(nt_write_msg(app_2ch_modelp, 
+						writep, cookiep, marup)){
+					disp_state = DISP_STATE_HTML_RESULT;
+					continue;
+				}
+			}
+			status_msg = writep->status_msg;
+			wclear(scrp);
+			continue;
+		case DISP_STATE_HTML_RESULT:
+			nresult = disp_html_result(writep);
+			if(0 == nresult){
+				if(!nt_read_thread(app_2ch_modelp))
+					break;
+				if(rwinp->data){
+					free_reslist_ctx(rwinp->data);
+					rwinp->data = NULL;
+				}
+			}else if(1 == nresult){
+				if(nt_write_msg(app_2ch_modelp, 
+						writep, cookiep, marup)){
+					if(0 == disp_html_result(writep)){
+						if(!nt_read_thread(app_2ch_modelp))
+							break;
+						if(rwinp->data){
+							free_reslist_ctx(rwinp->data);
+							rwinp->data = NULL;
+						}
+					}
+				}
+			}
+			disp_state = DISP_STATE_RESLIST;
+			ch = NT_KEY_NONE;
+			status_msg = writep->status_msg;
+			wclear(scrp);
+			continue;
 		default:
 		 	goto END_WHILE;
 		}/* end switch*/
@@ -209,7 +281,12 @@ static BOOL DoLoop(WINDOW *scrp)
 		}/* end switch*/
 	}/* end while */
 END_WHILE:
-	
+	if(cookiep)
+		nt_unload_cookie(cookiep);
+	if(marup)
+		nt_maru_2ch_free(marup);
+	if(writep)
+		nt_write_data_free(writep);
 	free_board_menu_ctx(bwinp->data);
 	free_threadlist_ctx(twinp->data);
 	free_reslist_ctx(rwinp->data);
