@@ -16,7 +16,8 @@
 #include	"net/nt_socket.h"
 #include	"net/nt_http.h"
 
-static int add_header(nt_http_response_header_tp, const char *line);
+static int add_header(nt_http_response_header_tp, const char *line,
+			nt_cookie_tp cookiep, const char *host);
 static int parse_status_code(const char *source);
 
 
@@ -46,7 +47,7 @@ BOOL nt_http_save_response_header(const char *out_path,
 	strcpy(rec.last_modified, responsep->last_modified);
 
 	log_path = nt_db_get_log_path();
-	dbm = dbm_open((char*)log_path, O_RDWR | O_CREAT, 0666);
+	dbm = dbm_open((char*)log_path, O_RDWR | O_CREAT, 0600);
 	if(dbm == NULL){
 		return FALSE;
 	}
@@ -86,11 +87,12 @@ nt_http_response_header_tp nt_http_alloc_response_header()
 }
 
 int nt_http_parse_response_header(int readfd, 
-		nt_http_response_header_tp responsep)
+		nt_http_response_header_tp responsep,
+		nt_cookie_tp cookiep, const char *host)
 {
 	assert(responsep != NULL);
 
-	char buf[256];
+	char buf[1024];
 	char c;
 	int idx = 0, state = 0;
 	int  nread;
@@ -112,12 +114,14 @@ int nt_http_parse_response_header(int readfd,
 				assert(state == 1);
 				state = 0;
 				buf[idx] = '\0';
-				if(0 == add_header(responsep, buf)){
+				if(0 == add_header(responsep, buf,
+							cookiep, host)){
 					return 1;
 				}
 				idx = 0;
 				break;
 			default:
+				state = 0;
 				buf[idx] = c;
 				idx++;
 				if(sizeof(buf) == idx)
@@ -133,7 +137,47 @@ int nt_http_parse_response_header(int readfd,
 }
 
 
-static int add_header(nt_http_response_header_tp headerp, const char *line)
+int nt_http_parse_response_header2(
+		const char *data, size_t data_len, 
+		nt_http_response_header_tp responsep)
+{
+	assert(responsep != NULL);
+
+	char buf[256];
+	char c;
+	int i;
+	int idx = 0, state = 0;
+
+	for(i = 0; i < data_len; i++){
+		c = data[i];
+		switch(c){
+		case '\r':
+			state = 1;
+			buf[idx] = '\0';
+			break;
+		case '\n':
+			assert(state == 1);
+			state = 0;
+			buf[idx] = '\0';
+			if(0 == add_header(responsep, buf, NULL, NULL)){
+				return i+1;
+			}
+			idx = 0;
+			break;
+		default:
+			state = 0;
+			buf[idx] = c;
+			idx++;
+			if(sizeof(buf) == idx)
+				return -1;
+			break;
+		}/* switch */
+	}/* end for */
+	return i;
+}
+
+static int add_header(nt_http_response_header_tp headerp, 	
+			const char *line, nt_cookie_tp cookiep, const char *host)
 {
 	char *cptr;
 	int len, num;
@@ -159,6 +203,11 @@ static int add_header(nt_http_response_header_tp headerp, const char *line)
 			return -1;
 		headerp->content_length = num;
 	}else if(0 == strncmp("Content-Type:", line, 13)){
+	}else if(0 == strncmp("Set-Cookie:", line, 11)){
+		if(!cookiep || !host)
+			return -1;
+		if(!nt_add_cookie(cookiep, host, line+11))
+			return -1;
 	}
 	return len;
 }
