@@ -47,12 +47,17 @@ BOOL nt_w_str_move(wchar_t *buf, size_t buf_len,
 	return TRUE;
 }
 
+
+
 wchar_t *nt_w_trim(const wchar_t *source)
 {
-	assert(source != NULL);
-	int len = wcslen(source);
 	int i, j, status;
 	wchar_t *cptr;
+	int len;
+
+	assert(source != NULL);
+
+	len = wcslen(source);
 
 	for(i=0; i<len; i++){
 		switch(source[i]){
@@ -188,13 +193,25 @@ wchar_t *nt_w_trim_quotes(const wchar_t *source)
 	return cptr;
 }
 
-char *nt_trim(const char *source)
+char *nt_trim2(const char *source, char *buf, size_t buf_len)
 {
-	assert(source != NULL);
-	int len = strlen(source);
 	int i, j, status;
 	char *cptr;
+	int len;
 
+	assert(source != NULL);
+
+	len = strlen(source);
+
+	if(!buf){
+		cptr = calloc(len+1, sizeof(char));
+		if(!cptr)
+			return NULL;
+	}else{
+		if(buf_len < len+1)
+			return NULL;
+		cptr = buf;
+	}
 	for(i=0; i<len; i++){
 		switch(source[i]){
 		case ' ':
@@ -211,9 +228,7 @@ char *nt_trim(const char *source)
 			break;
 	}/* end for */
 	if(i == len){
-		cptr = malloc(1);
-		if(cptr != NULL)
-			cptr[0] = '\0';
+		cptr[0] = L'\0';
 		return cptr;
 	}
 	for(j = len - 1; j > i; j--){
@@ -231,12 +246,44 @@ char *nt_trim(const char *source)
 		if(status == 0)
 			break;
 	}/* end for */
-	assert(i < j);
+	assert(i <= j);
 	len = j - i + 1;
-	cptr = malloc(len + 1);
-	if(cptr != NULL){
-		memcpy(cptr, source+i, len);
-		cptr[len] = '\0';
-	}
+	memcpy(cptr, source+i, len*sizeof(char));
+	cptr[len] = '\0';
 	return cptr;
 }
+
+char* nt_str_clone(const char* src)
+{
+	char *cptr;
+	cptr = malloc(strlen(src)+1);
+	if(!cptr)
+		return NULL;
+	strcpy(cptr, src);
+	return cptr;
+}
+
+char* nt_substr(const char* src, int start, int end)
+{
+	char *cptr;
+	int len;
+
+	assert(start >= 0);
+	assert(start <= end);
+
+	len = end - start;
+	cptr = malloc(len + 1);
+	if(!cptr)
+		return NULL;
+	
+	if(len == 0){
+		*cptr =  '\0';
+		return cptr;
+	}
+	
+	memcpy(cptr, src+start, len);
+	cptr[len] = '\0';
+	return cptr;
+}
+
+
